# Overview
This directory contains Python based scripts that are used specifically to initialize a managed ES cluster on AWS.
The scripts use the [Elasticsearch Python module](https://elasticsearch-py.readthedocs.io/en/v7.12.0/api.html#elasticsearch) to perform the actions listed below.

## Requirements
* Python 3.6

## Setup
Before using the scripts in this directory, you must install the required modules.
```shell
pip install -r requirements.txt --trusted-host artifactory-pub.bit9.local
```

## Running the Scripts Locally
Following are examples of how to run the scripts in this directory.
To learn more about how to use the scripts you may run `python <script-name>.py -h`.

**Create a New Index**

The following creates a new index on an elasticsearch instance running on `localhost`.
```shell
python create_new_index.py -e 'http://localhost:9200' -i 'livequery' -m '../../lq-common-es680/src/main/resources/mappings/livequery_mappings.json' -s '../../lq-common-es680/src/main/resources/settings/livequery_settings.json'
```

:information_source: On a managed ES service on AWS, you might need to pass the `-r` option for the aws region (e.g. `us-east-1`).

**Create Index Templates**

The following is an example of how to create an index template for the `livequeryresult` index against a running instance of elasticsearch locally.
```shell
python create_index_template.py -e 'http://localhost:9200' -i 'livequeryresult' -r 'us-east-1' -m '../../lq-common-es680/src/main/resources/mappings/livequery_mappings.json' -s '../../lq-common-es680/src/main/resources/settings/livequery_settings.json'
```

**Create or Switch Index Aliases**

E.g.
```shell
python switch_index_alias.py -e 'http://localhost:9200' -i 'livequery' -o 'livequery' -a 'a_livequery' -r 'us-east-1'
```

## Running the Scripts on the Cloud

These scripts are packaged into the `lq-init` docker image, which runs as a `Job` on a k8s cluster in EKS.
For more info, see [Dockerfile-init](https://gitlab.bit9.local/cb-defense/livequery/-/blob/master/Dockerfile-init) and the [lq-init](https://gitlab.bit9.local/cb-defense/livequery/-/tree/master/vdp/livequery/charts/lq-init) Helm chart for VDP.
