import argparse
import logging
import utils
import os

es_client = None


def main(args):
    es_host = args.es_host
    alias = args.alias
    region = args.region
    es_username = args.es_username
    es_password = args.es_password

    # Create es client
    logging.info(f'Checking if alias={alias} exists...')
    global es_client
    es_client = utils.create_es_client(es_host=es_host, region=region,
                                       es_username=es_username, es_password=es_password)

    value = es_client.indices.exists_alias(name=alias)
    logging.info('Alias exists='+ str(value))
    print(value)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Create a new index.')

    parser.add_argument('-e', '--es-host', dest='es_host', help='Elasticsearch host and port', required=True)
    parser.add_argument('-a', '--alias', dest='alias', help='Name of the index alias.', required=True)
    parser.add_argument('-r', '--aws-region', dest='region', default='us-east-1',
                        help='AWS region that the elasticsearch cluster is in. default = us-east-1.')
    parser.add_argument('-u', '--es-username', dest='es_username',
                        help='Username for ES basic auth.', default=os.environ.get('ES_USERNAME', None))
    parser.add_argument('-p', '--es-password', dest='es_password',
                        help='Password for ES basic auth.', default=os.environ.get('ES_PASSWORD', None))

    main(args=parser.parse_args())
