import argparse
import logging
import utils
import os

es_client = None


def main(args):
    es_host = args.es_host
    new_index_name = args.new_index_name
    old_index_name = args.old_index_name
    alias = args.alias
    region = args.region
    es_username = args.es_username
    es_password = args.es_password

    # Create es client
    logging.info('Creating ES client...')
    global es_client
    es_client = utils.create_es_client(es_host=es_host, region=region,
                                       es_username=es_username, es_password=es_password)

    logging.info('Creating alias {} for old index {} and new index {}...', alias, new_index_name, old_index_name)
    create_alias(new_index=new_index_name, old_index=old_index_name, alias=alias)


def create_alias(new_index, old_index, alias):
    """
    Creates a new alias, or switches an alias to a new index.

    :param new_index: name of index to switch alias to
    :param old_index: name of index to switch alias from
    :param alias: name of the index alias
    :return:
    """
    alias_actions = {
        'actions': [
            {
                'remove': {
                    'index': old_index,
                    'alias': alias
                }
            },
            {
                'add': {
                    'index': new_index,
                    'alias': alias
                }
            }
        ]
    }

    try:
        es_client.indices.put_alias(body=alias_actions, name=alias, index=[new_index])
    except Exception as e:
        logging.error('Failed to create aliases. Reason = {}', str(e))
        logging.exception(e)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Create a new index.')

    parser.add_argument('-e', '--es-host', dest='es_host', help='Elasticsearch host and port', required=True)
    parser.add_argument('-a', '--alias', dest='alias', help='Name of the index alias.', required=True)
    parser.add_argument('-i', '--new-index-name', dest='new_index_name', help='Name of the new index.', required=True)
    parser.add_argument('-o', '--old-index-name', dest='old_index_name', help='Name of the old index.', required=True)
    parser.add_argument('-r', '--aws-region', dest='region', default='us-east-1',
                        help='AWS region that the elasticsearch cluster is in. default = us-east-1.')
    parser.add_argument('-u', '--es-username', dest='es_username',
                        help='Username for ES basic auth.', default=os.environ.get('ES_USERNAME', None))
    parser.add_argument('-p', '--es-password', dest='es_password',
                        help='Password for ES basic auth.', default=os.environ.get('ES_PASSWORD', None))

    main(args=parser.parse_args())
