import sys
import json
import boto3
import logging
from requests_aws4auth import AWS4Auth
from elasticsearch import Elasticsearch, RequestsHttpConnection


def load_json_file(file_path):
    """
    Loads a json file and returns its content
    :param file_path: path to a file contain json content
    :return: parsed json object of the file
    """
    try:
        return json.load(open(file_path))
    except Exception as e:
        logging.error('Failed to load json file from {}.', file_path)
        logging.exception(e)
        sys.exit(1)


def create_es_client(es_host, region, es_username, es_password):
    # Create es client
    logging.info('Creating ES client...')

    if es_username and es_password:
        es_client = Elasticsearch(
            [es_host],
            http_auth=(es_username, es_password),
            port=443,
            use_ssl=True,
            ssl_assert_hostname=False
        )
    else:
        es_client = Elasticsearch(es_host)

    return es_client
